@@ -184,14 +184,14 @@ var NAVTREEINDEX =
 "LREADME.html",
 "encoder_guide.html#architecture_enc_gf_length",
 "group__aom__encoder.html#ga5a44302260efb45ebf560f7fb0b4352b",
-"group__codec.html#gaf452ede024bf9a378fa66443494070ba",
+"group__codec.html#gaf35aecefb8133a5474d0068119e6182c",
 "group__speed__features.html#ga95ee4b0969a41da950b5c23909d142c4",
-"structAV1__COMP.html#a5dd4bce670a858752380e59d8d8daaf9",
-"structCommonQuantParams.html",
-"structLV__MAP__COEFF__COST.html#a21ff28247f7c01445252cf0d4d157726",
-"structRefreshFrameInfo.html#abda267747d6fc4a0be09eaa6b43f636c",
-"structaom__codec__enc__cfg.html#a8695946812f24f3719aed80cff00aa29",
-"structcfg__options.html#a976938b694d797a9f1c3b0e09b0226af"
+"structAV1__COMP.html#a61ca5f788df7db66a40f902f8929bf3f",
+"structCommonQuantParams.html#a184dcbe8f484a0d1d224f367224a5379",
+"structLV__MAP__COEFF__COST.html#ac13625e52afc8b9f56490d9b4e3763c8",
+"structResizeCfg.html#a648d5bb8effb5ece1b5e7abcd4f2a197",
+"structaom__codec__enc__cfg.html#a8f8851455e06db026022d4b01671b122",
+"structcfg__options.html#aab0e968a76c1dd31fbfdee7b099b7828"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
