@@ -1,6 +1,5 @@
 var NAVTREEINDEX5 =
 {
-"structAV1__COMP.html#a5dd4bce670a858752380e59d8d8daaf9":[13,0,37,6],
 "structAV1__COMP.html#a61ca5f788df7db66a40f902f8929bf3f":[13,0,37,49],
 "structAV1__COMP.html#a62a2e36e5f53412363680d402a958ece":[13,0,37,38],
 "structAV1__COMP.html#a62bdce36b2cdeb4e2a9a5c03b8820afc":[13,0,37,23],
@@ -20,15 +19,14 @@ var NAVTREEINDEX5 =
 "structAV1__COMP.html#a7e0661a8322b19a27c9969d2898ed858":[13,0,37,25],
 "structAV1__COMP.html#a7ee7e00e3423b19eac935c9a27c14a8d":[13,0,37,73],
 "structAV1__COMP.html#a7f8997078cd563ed82f37e0b04e00b91":[13,0,37,14],
-"structAV1__COMP.html#a7f8eb526cc0e962a3f3500bff283db27":[13,0,37,112],
 "structAV1__COMP.html#a8172b1a8dc8d210fa745138938874fb7":[13,0,37,42],
 "structAV1__COMP.html#a81e0bda4dd2dff128613be4c1cd186fb":[13,0,37,70],
 "structAV1__COMP.html#a8431a87c6d3ed7cacf1d1d4b53eb15b1":[13,0,37,61],
-"structAV1__COMP.html#a852b890830dba74a6f4bce834380424f":[13,0,37,122],
+"structAV1__COMP.html#a852b890830dba74a6f4bce834380424f":[13,0,37,121],
 "structAV1__COMP.html#a8a6dffc3949931c07ab86f18539c3ab8":[13,0,37,11],
 "structAV1__COMP.html#a8e29879e2541a075abb94510dc698007":[13,0,37,71],
 "structAV1__COMP.html#a91905e3eeee006840918bd3aaf93bab7":[13,0,37,16],
-"structAV1__COMP.html#a91bbf499df1204752a95d8730108ea2b":[13,0,37,119],
+"structAV1__COMP.html#a91bbf499df1204752a95d8730108ea2b":[13,0,37,118],
 "structAV1__COMP.html#a98a22afbd13b9c7a14a1ad51d1bdf415":[13,0,37,48],
 "structAV1__COMP.html#a9987c30f368252cd197dbbfed940c469":[13,0,37,55],
 "structAV1__COMP.html#a9aea0ecc72af0b304c33dae392a884f6":[13,0,37,81],
@@ -39,7 +37,7 @@ var NAVTREEINDEX5 =
 "structAV1__COMP.html#aa2c5ad94c8bc0d7da5a4354bbe68301b":[13,0,37,75],
 "structAV1__COMP.html#aa3403fc90f89d25b1b18ed11e14384c1":[13,0,37,68],
 "structAV1__COMP.html#aa61580d294015592b73d58ca79e7f09a":[13,0,37,0],
-"structAV1__COMP.html#aa6e74802d8f8aecfaa32dce27d0f0c67":[13,0,37,114],
+"structAV1__COMP.html#aa6e74802d8f8aecfaa32dce27d0f0c67":[13,0,37,113],
 "structAV1__COMP.html#aa7f83fb36f70ef378393873e41a26f7e":[13,0,37,108],
 "structAV1__COMP.html#aaa416562780c42ed8fbc439a8e033f59":[13,0,37,19],
 "structAV1__COMP.html#ab73f758bfa8d3c1edea9981ecfe4ddf0":[13,0,37,95],
@@ -55,7 +53,7 @@ var NAVTREEINDEX5 =
 "structAV1__COMP.html#acafbb7d6233ce98630ee3d3da4e39c0b":[13,0,37,37],
 "structAV1__COMP.html#ad27d351fdb5c7202a8d362d79d030c58":[13,0,37,39],
 "structAV1__COMP.html#ad2c0908b11b789a2df0a90e563a433ea":[13,0,37,94],
-"structAV1__COMP.html#ad36e29542fdcc0b7c2c67e142381f252":[13,0,37,116],
+"structAV1__COMP.html#ad36e29542fdcc0b7c2c67e142381f252":[13,0,37,115],
 "structAV1__COMP.html#ad780d3cebefa7f76b212c0cb8de3f140":[13,0,37,29],
 "structAV1__COMP.html#ad7a2fbeb7e11ff525044f82b73d1f56b":[13,0,37,110],
 "structAV1__COMP.html#ad889729b799aade846fe7a2e5d27dea8":[13,0,37,2],
@@ -66,10 +64,10 @@ var NAVTREEINDEX5 =
 "structAV1__COMP.html#ae0e9447a3719724582351cd5e5d4ee72":[13,0,37,1],
 "structAV1__COMP.html#ae17f8b5096955a0bb3a553c719c362e3":[13,0,37,83],
 "structAV1__COMP.html#ae361e3256289fc9e62328dab440e7691":[13,0,37,104],
-"structAV1__COMP.html#ae6059c5763ab0b220da971b11b7002f7":[13,0,37,117],
+"structAV1__COMP.html#ae6059c5763ab0b220da971b11b7002f7":[13,0,37,116],
 "structAV1__COMP.html#ae69f2f43c6b433ab69619b46f8182127":[13,0,37,106],
 "structAV1__COMP.html#ae99e19b47623d78945a150a2bb590e0e":[13,0,37,52],
-"structAV1__COMP.html#aecdcb0ad8bfc529a749c41fc82ca5f8e":[13,0,37,115],
+"structAV1__COMP.html#aecdcb0ad8bfc529a749c41fc82ca5f8e":[13,0,37,114],
 "structAV1__COMP.html#aedbfd57eeefc819431091d2be25cab11":[13,0,37,15],
 "structAV1__COMP.html#aefe4d284d22f10945fe1c18cb2a095a4":[13,0,37,98],
 "structAV1__COMP.html#af1ec2b7dd9f111bc7a4f38bf8c254e61":[13,0,37,63],
@@ -86,7 +84,6 @@ var NAVTREEINDEX5 =
 "structAV1__COMP__DATA.html#a7eceaa9acbe84ded227d46d76b81b2cf":[13,0,38,0],
 "structAV1__COMP__DATA.html#a8b121a19fa5662ccd07a077fd8577d88":[13,0,38,1],
 "structAV1__COMP__DATA.html#a9e30bb6f95c7ab4a35d9fff4ea71db2d":[13,0,38,6],
-"structAV1__COMP__DATA.html#aec84bbb9c78a22a4be5a0ff14ea680b2":[13,0,38,9],
 "structAV1__COMP__DATA.html#af3e70471d853389cc0cab73c1c010f94":[13,0,38,3],
 "structAV1__COMP__DATA.html#af847b50bfbb7ac434321113ce5eb8c44":[13,0,38,2],
 "structAV1__COMP__DATA.html#aff89c99a55845a0489681ad33c7647ea":[13,0,38,7],
@@ -249,5 +246,8 @@ var NAVTREEINDEX5 =
 "structCommonModeInfoParams.html#ada12fea8f2e30e7a0ea06ccb381c6ee8":[13,0,57,11],
 "structCommonModeInfoParams.html#ae4ec94f26ebdbe07d76700e3a33fae78":[13,0,57,0],
 "structCommonModeInfoParams.html#ae9e5d24e6af7f50d83d89bba2f95c332":[13,0,57,9],
-"structCommonModeInfoParams.html#af433ad72e0ce77b148f933667a815650":[13,0,57,8]
+"structCommonModeInfoParams.html#af433ad72e0ce77b148f933667a815650":[13,0,57,8],
+"structCommonQuantParams.html":[13,0,58],
+"structCommonQuantParams.html#a01d6e6e663e708fd230dfa8a4d771320":[13,0,58,4],
+"structCommonQuantParams.html#a0bec28af02aa55ca9f2d44e212fff445":[13,0,58,12]
 };
