@@ -1,8 +1,5 @@
 var NAVTREEINDEX6 =
 {
-"structCommonQuantParams.html":[13,0,58],
-"structCommonQuantParams.html#a01d6e6e663e708fd230dfa8a4d771320":[13,0,58,4],
-"structCommonQuantParams.html#a0bec28af02aa55ca9f2d44e212fff445":[13,0,58,12],
 "structCommonQuantParams.html#a184dcbe8f484a0d1d224f367224a5379":[13,0,58,17],
 "structCommonQuantParams.html#a2ad05f39cabcdd12d9bd34136788793a":[13,0,58,9],
 "structCommonQuantParams.html#a357284012595df64bd5d687fa667825e":[13,0,58,7],
@@ -249,5 +246,8 @@ var NAVTREEINDEX6 =
 "structLAYER__CONTEXT.html#ac84886e42f345445136e78d701fec643":[12,2,10,0,6],
 "structLAYER__CONTEXT.html#af1c6b09cc85e7314d989aae83a7b28d5":[12,2,10,0,1],
 "structLV__MAP__COEFF__COST.html":[13,0,89],
-"structLV__MAP__COEFF__COST.html#a14f9d4c6db67fc6b8f05bc8dded96a67":[13,0,89,2]
+"structLV__MAP__COEFF__COST.html#a14f9d4c6db67fc6b8f05bc8dded96a67":[13,0,89,2],
+"structLV__MAP__COEFF__COST.html#a21ff28247f7c01445252cf0d4d157726":[13,0,89,5],
+"structLV__MAP__COEFF__COST.html#a3b1604ef5cdf5ef6d5f80b1a2eff97c9":[13,0,89,0],
+"structLV__MAP__COEFF__COST.html#a524b66066193b2d558d701569a309cd2":[13,0,89,4]
 };
